Proteome
=================

.. autoclass:: shephard.proteome.Proteome


Proteome functions
....................

.. autofunction:: shephard.proteome.Proteome.check_unique_ID
.. autofunction:: shephard.proteome.Proteome.attributes
.. autofunction:: shephard.proteome.Proteome.attribute
.. autofunction:: shephard.proteome.Proteome.add_attribute
.. autofunction:: shephard.proteome.Proteome.remove_attribute
.. autofunction:: shephard.proteome.Proteome.__iter__
.. autofunction:: shephard.proteome.Proteome.__contains__
.. autofunction:: shephard.proteome.Proteome.__getitem__
.. autofunction:: shephard.proteome.Proteome.__len__



Protein functions
....................

.. autofunction:: shephard.proteome.Proteome.proteins
.. autofunction:: shephard.proteome.Proteome.protein
.. autofunction:: shephard.proteome.Proteome.add_protein
.. autofunction:: shephard.proteome.Proteome.add_proteins
.. autofunction:: shephard.proteome.Proteome.remove_protein
.. autofunction:: shephard.proteome.Proteome.remove_proteins


Domain properties
....................

.. autofunction:: shephard.proteome.Proteome.domains
.. autofunction:: shephard.proteome.Proteome.unique_domain_types
.. autofunction:: shephard.proteome.Proteome.get_domains_by_type


Site properties
....................

.. autofunction:: shephard.proteome.Proteome.sites
.. autofunction:: shephard.proteome.Proteome.unique_site_types
.. autofunction:: shephard.proteome.Proteome.get_sites_by_type


Track properties
....................

.. autofunction:: shephard.proteome.Proteome.unique_track_names
.. autofunction:: shephard.proteome.Proteome.track_names_to_track_type






   
